@@ -33,7 +33,7 @@ from gettext import gettext as _
 gettext.textdomain('testdrive')
 
 ISO_REPOSITORY = ['cdimage', 'releases']
-MEM_SIZE_TAB = ['256', '384', '512', _('Other...')]
+MEM_SIZE_TAB = ['256', '384', '512', '1024', _('Other...')]
 DISK_SIZE_TAB = ['4', '6', '8', _('Other...')]
 
 class PreferencesTestdrivegtkDialog(gtk.Dialog):
@@ -246,9 +246,11 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
 			self.cbe_mem_size.set_active(1)
 		elif self.td.MEM == '512':
 			self.cbe_mem_size.set_active(2)
+		elif self.td.MEM == '1024':
+			self.cbe_mem_size.set_active(3)
 		else:
 			self.cbe_mem_size.append_text(self.td.MEM)
-			self.cbe_mem_size.set_active(4)
+			self.cbe_mem_size.set_active(5)
 
 		# Disk Size
 		if self.td.DISK_SIZE == '4G':
